starcluster.tests.templates.sge_balancer

Package starcluster :: Package tests :: Package templates :: Module sge_balancer |
[hide private]
[frames] | no frames]

# Module sge_balancer

source code

Variables | [hide private]
| qhost_xml = ``'``<?xml version=\'1.0\'?>\n<qhost xmlns:xsd="http:/``...``
| qstat_xml = ``'``<?xml version=\'1.0\'?>\n<job_info xmlns:xsd="ht``...``
| loaded_qhost_xml = ``'``<?xml version=\'2.0\'?>\n<qhost xmlns:xsd=``...``
| qacct_txt = ``'``=================================================``...``
| loaded_qstat_xml = ``'``<?xml version=\'1.0\'?>\n<job_info xmlns:``...``
| __package__ = `None` hash(x)

Variables Details | [hide private]

  ### qhost_xml Value:
      '''<?xml version=\'1.0\'?>
      <qhost xmlns:xsd="http://gridengine.sunsource.net/source/browse/*check
      out*/gridengine/source/dist/util/resources/schemas/qhost/qhost.xsd?rev
      ision=1.2">
       <host name=\'global\'>
         <hostvalue name=\'arch_string\'>-</hostvalue>
         <hostvalue name=\'num_proc\'>-</hostvalue>
         <hostvalue name=\'load_avg\'>-</hostvalue>
      ...

  ### qstat_xml Value:
      '''<?xml version=\'1.0\'?>
      <job_info  xmlns:xsd="http://gridengine.sunsource.net/source/browse/*c
      heckout*/gridengine/source/dist/util/resources/schemas/qstat/qstat.xsd
      ?revision=1.11">
        <queue_info>
          <job_list state="running">
            <JB_job_number>1</JB_job_number>
            <JAT_prio>0.55500</JAT_prio>
      ...

  ### loaded_qhost_xml Value:
      '''<?xml version=\'2.0\'?>
      <qhost xmlns:xsd="http://gridengine.sunsource.net/source/browse/*check
      out*/gridengine/source/dist/util/resources/schemas/qhost/qhost.xsd?rev
      ision=1.2">
       <host name=\'global\'>
         <hostvalue name=\'arch_string\'>-</hostvalue>
         <hostvalue name=\'num_proc\'>-</hostvalue>
         <hostvalue name=\'load_avg\'>-</hostvalue>
      ...

  ### qacct_txt Value:
      '''==============================================================
      qname        all.q
      hostname     domU-12-31-38-00-A6-41.compute-1.internal
      group        root
      owner        root
      project      NONE
      department   defaultdepartment
      jobname      sleep
      ...

  ### loaded_qstat_xml Value:
      '''<?xml version=\'1.0\'?>
      <job_info  xmlns:xsd="http://gridengine.sunsource.net/source/browse/*c
      heckout*/gridengine/source/dist/util/resources/schemas/qstat/qstat.xsd
      ?revision=1.11">
        <queue_info>
          <job_list state="running">
            <JB_job_number>385</JB_job_number>
            <JAT_prio>0.55500</JAT_prio>
      ...